/*
 * Copyright (C) 2017 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana
 *
 * This file is part of blendb.
 *
 * blendb is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * blendb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with blendb.  If not, see <http://www.gnu.org/licenses/>.
 */

import * as express from "express";

/**
 * Creates a middleware to handle errors proper to each API version.
 * @param config - API version.
 */
export function ErrorMw(config: string): express.ErrorRequestHandler {
    const handlers: { [key: string]: express.ErrorRequestHandler } = {
        "v1": function(err, req, res, next) {
            if (err.ramlNotFound) {
                const splited = err.toString().split(" ");
                const method = splited[1];
                const route = "/v1" + splited[2];
                res.status(404).json({ error: "Cannot " + method + " " + route });
            }

            else if (err.ramlValidation) {
                res.status(400).json({
                    error: "Bad request: Some problems with this request were found"
                    , requestErrors: err.requestErrors
                });
            }

            else if (err.ramlAuthorization) {
                res.status(401).json({
                    error: "Unauthorized: Some problems with your authentication were found, try to authenticate again"
                    , requestErrors: err.authorizationErrors
                });
            }

            else {
                res.status(400).json({error: err.toString()});
            }

            return;
        },

        "default": function(err, req, res, next) {
            next(err);
            return;
        }
    };

    if (handlers[config]) {
        return handlers[config];
    }

    else {
        return handlers.default;
    }
};
