/*
 * Copyright (C) 2016 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana
 *
 * This file is part of blend.
 *
 * blend is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * blend is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with blend.  If not, see <http://www.gnu.org/licenses/>.
 */

import { Metric } from "../core/metric";
import { Dimension } from "../core/dimension";
import { Clause } from "../core/clause";

/**
 * Internal representation of a query in BlenDB perspective.
 */
export interface QueryOpts {
    /** Set of metrics of the query. */
    metrics: Metric[];
    /** Set of dimensions of the query. */
    dimensions: Dimension[];
    /** Set of clauses of the query. */
    clauses?: Clause[];
    /** List of metrics and dimensions to sort the query. */
    sort?: (Metric|Dimension)[];
}

export class Query {
    /** Set of metrics of the query. */
    public readonly metrics: Metric[];
    /** Set of dimensions of the query. */
    public readonly dimensions: Dimension[];
    /** Set of clauses of the query. */
    public readonly clauses: Clause[];
    /** List of metrics and dimensions to sort the query. */
    public readonly sort: (Metric|Dimension)[];
    /**
     * Create Query
     * @param opts - Parameters required to create a query.
     */
    constructor(opts: QueryOpts){
        this.metrics = opts.metrics.map((i) => i);
        this.dimensions = opts.dimensions.map((i) => i);
        this.clauses = (opts.clauses) ? opts.clauses.map((i) => i) : [];
        this.sort = (opts.sort) ? opts.sort.map((i) => i) : [];
    }
}
