/*
 * Copyright (C) 2016 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana
 *
 * This file is part of blend.
 *
 * blend is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * blend is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with blend.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Available aggregation function to metrics.
 */
export enum AggregationType {
    /** Used as error code. So suitable aggregation found. */
    NONE,
    /** Sum aggregation function. Sum of all registers. */
    SUM,
    /** Average aggregation function. Average of all registers. */
    AVG,
    /** Count agggreation function. Count the number of registers. */
    COUNT,
    /** Maximum aggregation function. The biggest value of all registers. */
    MAX,
    /** Minimum aggregation function. The smallest value of all registers. */
    MIN
};

/**
 * Available relationships between sub dimensions and its parents.
 */
export enum RelationType {
    /** Used when there are no relation. The dimension is not a sub dimension. */
    NONE,
    /**
     * Day relation.
     * The parent is a timestamp and the dimension is only the day of
     * the timestamp.
     */
    DAY,
    /**
     * Month relation.
     * The parent is a timestamp and the dimension is only the month of
     * the timestamp.
     */
    MONTH,
    /**
     * Year relation.
     * The parent is a timestamp and the dimension is only the year of
     * the timestamp.
     */
    YEAR,
};

/**
 * Available data types for metrics, dimensions and source members.
 * In other words types that BlenDB can handle.
 */
export enum DataType {
    /** Used as error code when no suitable type is found. */
    NONE,
    /** Interger type. */
    INTEGER,
    /** Floating number type. */
    FLOAT,
    /** String type. */
    STRING,
    /** Timestamp type. ISO format */
    DATE,
    /** True/False type. */
    BOOLEAN,
    /**
     * Enumerable type.
     * Custom type, that only accepts a set of previeous defined values.
     * Custom enumeration defined in configuration file.
     */
    ENUMTYPE
};
