/*
 * Copyright (C) 2018 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana
 *
 * This file is part of blend.
 *
 * blend is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * blend is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with blend.  If not, see <http://www.gnu.org/licenses/>.
 */

/** Parameters used to create a Enumerable type object. */
export interface EnumTypeOptions {
    /** The type name. */
    name: string;
    /** The allowed values to this type. */
    values: string[];
}

/**
 * Defines a custom data type.
 * This custom type has one restriction. Only a finite
 * set o values is allowed to this type. All the
 * valid values to this type are set in its definition.
 */
export class EnumType {
    /** The type name. */
    public name: string;
    /** The allowed values to this type. */
    public values: string[];

    /**
     * Create a enumerable type definition.
     * @param options - Parameters required to create a enumerable type.
     */
    constructor(options: EnumTypeOptions) {
        this.name = options.name;
        this.values = options.values;
    }

    /** Gets a string description of this enumerable type. */
    public strOptions(): EnumTypeOptions {
        return{
            name: this.name,
            values: this.values
        };
    }
}
