/*
 * Copyright (C) 2018 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana
 *
 * This file is part of blendb.
 *
 * blendb is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * blendb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with blendb.  If not, see <http://www.gnu.org/licenses/>.
 */

import {RelationType, DataType , AggregationType} from "../common/types";

/**
 * Enum's handler. Manage parse through the project.
 */
export class EnumHandler {

    /**
     * Parse an enum(Data type) to string.
     * @param a - Data type to be stringified.
     */
    public static stringfyDataType(a: DataType): string {
        switch (a) {
            case DataType.INTEGER:
                return "integer";
            case DataType.FLOAT:
                return "float";
            case DataType.STRING:
                return "string";
            case DataType.DATE:
                return "date";
            case DataType.BOOLEAN:
                return "boolean";
            case DataType.ENUMTYPE:
                return "enumtype";
            default:
                return  "";
        }
    }

    /**
     * Parse a string to enum(Data Type).
     * @param str - Data type in string format.
     */
    public static parseDataType (str: string): DataType {
        str = str.toLocaleLowerCase();
        switch (str) {
            case "integer":
                return DataType.INTEGER;
            case "float":
                return DataType.FLOAT;
            case "string":
                return DataType.STRING;
            case "date":
                return DataType.DATE;
            case "boolean":
                return DataType.BOOLEAN;
            case "enumtype":
                return DataType.ENUMTYPE;
            default:
                return  DataType.NONE;
        }
    }

    /**
     * Parse a string to enum(Relation Type).
     * @param r - Relation in string format.
     */
    public static parseRelationType(r: string): RelationType {
        switch (r) {
            case "day":
                return RelationType.DAY;
            case "month":
                return RelationType.MONTH;
            case "year":
                return RelationType.YEAR;
            default:
                return RelationType.NONE;
        }
    }

    /**
     * Parse an enum(Relation Type) to string.
     * @param r - Relation to be stringified.
     */
    public static stringifyRelationType(r: RelationType): string {
        switch (r) {
            case RelationType.DAY:
                return "day";
            case RelationType.MONTH:
                return "month";
            case RelationType.YEAR:
                return "year";
            default:
                return "";
        }
    }

    /**
     * Parse an enum(Aggregation Type) to string.
     * @param a - Aggregation function to be stringified.
     */
    public static stringifyAggrType(a: AggregationType): string {
        switch (a) {
            case AggregationType.SUM:
                return "sum";
            case AggregationType.AVG:
                return "avg";
            case AggregationType.COUNT:
                return "count";
            case AggregationType.MAX:
                return "max";
            case AggregationType.MIN:
                return "min";
            default:
                return  "";
        }
    }

    /**
     * Parse a string to enum(Aggregation Type).
     * @param str - Aggregation function in string format.
     */
    public static parseAggrType (str: string): AggregationType {
        switch (str) {
            case "sum":
                return AggregationType.SUM;
            case "avg":
                return AggregationType.AVG;
            case "count":
                return AggregationType.COUNT;
            case "min":
                return AggregationType.MIN;
            case "max":
                return AggregationType.MAX;
            default:
                return AggregationType.NONE;
        }
    }

}
