/*
 * Copyright (C) 2017 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana
 *
 * This file is part of blendb.
 *
 * blendb is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * blendb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with blendb.  If not, see <http://www.gnu.org/licenses/>.
*/

import { View } from "../core/view";
import { Metric } from "../core/metric";
import { Dimension } from "../core/dimension";
import { Query } from "../common/query";

export interface EngineScenario {
    /**
     * All metrics from /config/*
     */
    metrics: {[key: string]: Metric};
    /**
     * All dimensions from /config/*
     */
    dimensions: {[key: string]: Dimension};
    /**
     * subDimensions from scenario
     */
    subDimensions: {[key: string]: Dimension};
    /**
     * Metric that does not exist on /config/*
     */
    wrongMet: Metric;
    /**
     * Dimension that does not exist on /config/*
     */
    wrongDim: Dimension;
    /**
     * All views from /config/*
     */
    views: {[key: string]: View};
    /**
     * Query that have all metrics and dimensions
     */
    queryMetsDims: Query;
    /**
     * Query with an invalid metric
     */
    queryNoMets: Query;
    /**
     * Query with an invalid dimension
     */
    queryNoDims: Query;
    /**
     * Query that matches Product
     */
    queryProduct: Query;
    /**
     * Product View
     */
    viewProduct: View;
    /**
     * Query that matches ActiveSeller
     */
    queryActive: Query;
    /**
     * ActiveSeller View
     */
    viewActiveSeller: View;
    /**
     * Query with no metrics and dimensions formed of subdimensions
     */
    querySubDim: Query;
    /**
     * A query that contains a subdimentions without a parent
     */
    queryNoParent: Query;
}

export interface AdapterScenario {
    /**
     * Product View
     */
    materializedView: View;
    /**
     * View that contains client name and it's sum quantity, and is
     * sorted based on quantity
     */
    sortView: View;
    /**
     * View that contains subDimensions based on date, such as day,
     * month and year
     */
    subDimensionView: View;
    /**
     * View that contains itself, which is product's View
     */
    joinWithOneView: View;
    /**
     * View that contains sold items on the day that is equals the last
     * day of validity
     */
    filterWithEqual: View;
    /**
     * View that contains metrics and dimensions from View Sell and dimensions
     * from View Client
     */
    reduceAsView: View;
    /**
     * View that contains the avererage product's bought with client's name
     */
    filterAverageBought: View;
    /**
     * View that contains the data from operation AND between clauses,
     * which is product's that was sold expired and have a value higher than
     * ten
     */
    multipleClause: View;
    /**
     * View that represent's the same data as multipleClause however with,
     * the operation OR between the filteres , since we use only one clause
     */
    singleClause: View;
    /**
     * View that contais the name of the client and the name of the product,
     * that the client has bought
     */
    joinWithNoMetrics: View;
    /**
     * View that contains the name,sex and age from View Seller
     */
    growOneView: View;
    /**
     * View that contains the seller id and how many sell's he has done
     */
    JoinWithAncestors: View;
}

export interface DataCtrlScenario {
    /**
     * Dimension that does not exist on /config/*
     */
    wrongMet: Query;
    /**
     * Dimension that does not exist on /config/*
     */
    wrongDim: Query;
    /**
     * A query that returns the average quantity of buyouts related
     * from provider
     */
    correct: Query;
    /**
     * A query that returns the average pricein related from it's name
     * and it's id
     */
    clausal: Query;
}
